@@ -1,5 +1,5 @@
 from rasa.core.events import Event
-from rasa.core.actions.action import Action, ActionUtterTemplate, create_bot_utterance
+from rasa.core.actions.action import Action, create_bot_utterance
 
 from typing import Any, List, Text, Dict, Optional
 import logging
